==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/MassIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MassIndexIndicatorStrategy } from "./MassIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MassIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MassIndexIndicator, _super);
    function MassIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MassIndexIndicator.prototype.bi = function () {
        return new MassIndexIndicator();
    };
    MassIndexIndicator.prototype.get_abm = function () {
        return new MassIndexIndicatorStrategy();
    };
    Object.defineProperty(MassIndexIndicator.prototype, "abm", {
        get: function () {
            return this.get_abm();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.prototype.get_abz = function () {
        return MassIndexIndicator.$;
    };
    Object.defineProperty(MassIndexIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.$t = markType(MassIndexIndicator, 'MassIndexIndicator', StrategyBasedIndicator.$);
    return MassIndexIndicator;
}(StrategyBasedIndicator));
export { MassIndexIndicator };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/MassIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MassIndexIndicatorStrategy } from "./MassIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MassIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MassIndexIndicator, _super);
    function MassIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MassIndexIndicator.prototype.bj = function () {
        return new MassIndexIndicator();
    };
    MassIndexIndicator.prototype.get_abv = function () {
        return new MassIndexIndicatorStrategy();
    };
    Object.defineProperty(MassIndexIndicator.prototype, "abv", {
        get: function () {
            return this.get_abv();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.prototype.get_ab8 = function () {
        return MassIndexIndicator.$;
    };
    Object.defineProperty(MassIndexIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.$t = markType(MassIndexIndicator, 'MassIndexIndicator', StrategyBasedIndicator.$);
    return MassIndexIndicator;
}(StrategyBasedIndicator));
export { MassIndexIndicator };
